Plotting spectra
================

General plotting
----------------

.. currentmodule:: penguins

.. autofunction:: subplots

.. autofunction:: subplots2d

|v|

.. autofunction:: mkplot

|v|

.. autofunction:: mkplots

|v|

.. autofunction:: mkinset

|v|

.. autofunction:: tight_layout

|v|

.. autofunction:: show

|v|

.. autofunction:: savefig

|v|

.. autofunction:: pause

|v|

1D plotting interfaces
----------------------

.. currentmodule:: penguins.pgplot

.. autofunction:: _stage1d

|v|

.. autofunction:: _mkplot1d

|v|

2D plotting interfaces
----------------------

.. autofunction:: _stage2d

|v|

.. autofunction:: _mkplot2d

|v|

.. autofunction:: _find_baselev

|v|

Auxiliary plotting utilities
----------------------------

.. currentmodule:: penguins

.. autofunction:: style_axes

|v|

.. autofunction:: xmove

|v|

.. autofunction:: ymove

|v|

.. autofunction:: cleanup_axes

|v|

.. autofunction:: cleanup_figure

|v|

.. autofunction:: set_palette

|v|

.. autofunction:: color_palette

|v|

.. currentmodule:: penguins.pgplot

.. autoclass:: PlotHoldingArea
   
|v|

.. autoclass:: PlotProperties

|v|

.. autoclass:: PlotObject1D

|v|

.. autoclass:: PlotObject2D
